@@ -1,11 +1,9 @@
-#![allow(clippy::needless_return)]
 #![feature(box_syntax)]
 #![feature(map_first_last)]
 #![feature(arbitrary_enum_discriminant)]
 // #![deny(missing_docs)]
-
-//! # Notedown AST
-
+#![allow(clippy::needless_return)]
+#![doc = include_str!("../Readme.md")]
 pub mod command;
 mod errors;
 #[cfg(feature = "lsp")]
