@@ -1,5 +1,3 @@
-use super::*;
-
 mod detailed;
 mod item;
 mod ordered;
@@ -8,13 +6,21 @@ mod prefix;
 
 pub use self::{detailed::DetailedList, item::ListItem, ordered::OrderedList, orderless::OrderlessList, prefix::ListPrefixSymbol};
 
+use super::*;
+use crate::{NoteError, Result};
+
+/// List like nodes
+/// Basically can be classified as ordered and orderless
 #[derive(Clone, Eq, PartialEq, Hash)]
 pub enum ListView {
+    /// Ordered list
     Ordered(Box<OrderedList>),
+    /// Orderless list
     Orderless(Box<OrderlessList>),
 }
 
 impl ListView {
+    /// Returns the children nodes of this list
     #[inline]
     pub fn children(&self) -> &Vec<ListItem> {
         match self {
@@ -22,6 +28,7 @@ impl ListView {
             Self::Orderless(v) => &v.children,
         }
     }
+    /// Returns the mutable children nodes of this list
     #[inline]
     pub fn children_mut(&mut self) -> &mut Vec<ListItem> {
         match self {
@@ -29,10 +36,15 @@ impl ListView {
             Self::Orderless(v) => &mut v.children,
         }
     }
+    /// Returns the first prefix of this list
     #[inline]
-    pub fn first_prefix(&self) -> Option<&ListPrefixSymbol> {
-        self.children().first().map(|f| &f.prefix.value)
+    pub fn first_prefix(&self) -> Result<&ListPrefixSymbol> {
+        match self.children().first() {
+            None => Err(NoteError::runtime_error("Not a valid list")),
+            Some(s) => Ok(&s.prefix.value),
+        }
     }
+    /// Check if this list is ordered
     #[inline]
     pub fn is_ordered(&self) -> bool {
         matches!(self, Self::Ordered(_))
@@ -40,21 +52,13 @@ impl ListView {
 }
 
 impl ListView {
-    /// ## Ordered List
-    /// ```note
-    /// 1. part1
-    /// 2. part2
-    ///    part2
-    /// 3. part3
-    ///
-    /// 4. part4
-    /// ```
+    /// Constructor of [`OrderedList`]
     #[inline]
     pub fn ordered_list(children: Vec<ListItem>) -> Self {
         let list = OrderedList { first_order: 0, children };
         Self::Ordered(box list)
     }
-
+    /// Constructor of [`OrderlessList`]
     #[inline]
     pub fn orderless_list(children: Vec<ListItem>) -> Self {
         let list = OrderlessList { children };
@@ -63,10 +67,12 @@ impl ListView {
 }
 
 impl ASTKind {
+    /// Constructor of [`OrderedList`]
     #[inline]
     pub fn ordered_list(children: Vec<ListItem>, r: MaybeRanged) -> ASTNode {
         ListView::ordered_list(children).into_node(r)
     }
+    /// Constructor of [`OrderlessList`]
     #[inline]
     pub fn orderless_list(children: Vec<ListItem>, r: MaybeRanged) -> ASTNode {
         ListView::orderless_list(children).into_node(r)
