@@ -66,7 +66,10 @@ into_node![
     OrderedList   => (ListView::Ordered ,     box),
     OrderlessList => (ListView::Orderless ,   box),
     TableView     => (ASTKind::TableView,     ref),
-    SimpleTable  =>  (TableView::SimpleTable, box),
+    SimpleTable   => (TableView::SimpleTable, box),
+    SmartLink     => (ASTKind::LinkNode,      ref),
+    ImageLink     => (SmartLink::Image,       box),
+    HyperLink     => (SmartLink::Normal,      box),
     CodeNode      => (ASTKind::CodeNode,      box),
     MathNode      => (ASTKind::MathNode,      box),
     TextSpan      => (ASTKind::TextSpan,      box),
